@@ -26,8 +26,8 @@ pub mod developer_type;
 pub use self::developer_type::DeveloperType;
 pub mod download_url_list;
 pub use self::download_url_list::DownloadUrlList;
-pub mod dynamic_world_row;
-pub use self::dynamic_world_row::DynamicWorldRow;
+pub mod dynamic_content_row;
+pub use self::dynamic_content_row::DynamicContentRow;
 pub mod error;
 pub use self::error::Error;
 pub mod favorite;
@@ -54,6 +54,16 @@ pub mod finish_file_data_upload_request;
 pub use self::finish_file_data_upload_request::FinishFileDataUploadRequest;
 pub mod friend_status;
 pub use self::friend_status::FriendStatus;
+pub mod info_push;
+pub use self::info_push::InfoPush;
+pub mod info_push_data;
+pub use self::info_push_data::InfoPushData;
+pub mod info_push_data_article;
+pub use self::info_push_data_article::InfoPushDataArticle;
+pub mod info_push_data_article_content;
+pub use self::info_push_data_article_content::InfoPushDataArticleContent;
+pub mod info_push_data_clickable;
+pub use self::info_push_data_clickable::InfoPushDataClickable;
 pub mod instance;
 pub use self::instance::Instance;
 pub mod instance_platforms;
